<?php

/**
 * @file
 * diff_different.admin.inc
 */

/**
 * Global admin settings form.
 *
 * @param array $form
 * @param array $form_state
 *
 * @return array $form
 */
function diff_different_admin_settings($form, $form_state) {

  $form['diff_different_content_types'] = array(
    '#title' => t('Select where the <em>diff</em> should be inserted.'),
    '#type' => 'fieldset',
    '#collapsible' => FALSE,
  );
  $form['diff_different_content_types']['diff_different_relative_weight'] = array(
    '#type' => 'select',
    '#title' => t('Position of the diff'),
    '#default_value' => variable_get('diff_different_relative_weight', 1),
    '#options' => array(
      -1 => t('Above'),
      1 => t('Below'),
    ),
    '#description' => t('This is relative to the content field selected below. <br/>The most common choice is the <em>Body</em> field, if it exists.'),
  );

  foreach (node_type_get_types() as $machine_name => $node_type) {

    $content_type_field_names = array_keys(field_read_fields(array('bundle' => $machine_name)));

    $options = array('' => '--' . t('Disabled') . '--');
    foreach ($content_type_field_names as $field_name) {
      $instance = field_info_instance('node', $field_name, $machine_name);
      $options[$field_name] = $instance['label'];
    }
    $form['diff_different_content_types']["diff_different_{$machine_name}_field"] = array(
      '#type' => 'select',
      '#title' => $node_type->name,
      '#default_value' => variable_get("diff_different_{$machine_name}_field"),
      '#options' => $options,
    );
  }

  $form['diff_different_revision_scenario'] = array(
    '#type' => 'radios',
    '#title' => t("Which pair of revisions should be <em>diffed</em>?"),
    '#default_value' => (int)variable_get('diff_different_revision_scenario'),
    '#options' => array(
      0 => t('Latest author revision on the left, latest editor revision after that on the right'),
      1 => t('Very last revision on the right, revision before that on the left')
    ),
    '#description' => t('The first option only applies when two or more users have edited the same node. The second option does not care who made the changes.'),
  );
  return system_settings_form($form);
}
